@@ -34,9 +34,9 @@ def load_env():
                 val = _format_val(val)
                 os.environ[key] = val
 
-    sys.path += (os.environ['CRATIS_APP_PATH'], )
+    sys.path += (os.environ.get('CRATIS_APP_PATH', '.'), )
 
-    if os.path.exists(os.environ['CRATIS_APP_PATH'] + os.sep + 'settings.py'):
+    if os.path.exists(os.environ.get('CRATIS_APP_PATH', '.') + os.sep + 'settings.py'):
         os.environ.setdefault("DJANGO_SETTINGS_MODULE", "settings")
     else:
         os.environ.setdefault("DJANGO_SETTINGS_MODULE", "cratis.settings")
\ No newline at end of file
